@@ -1,6 +1,5 @@
 from robotpy_toolkit_7407.sensors.photonvision.photon_camera import PhotonCamera
 from photonvision import PhotonUtils
-from wpimath.geometry import Pose2d, Pose3d, Rotation2d, Translation2d
 from robotpy_apriltag import AprilTagFieldLayout
 from robotpy_toolkit_7407.sensors.gyro import Gyro
 
@@ -20,7 +19,7 @@ class PhotonOdometry:
     def getRobotPose(self):
         target = self.camera.latest_target
 
-        if target.relative_pose is None:
+        if target is None:
             return None
 
         return PhotonUtils.estimateFieldToRobot(
